rebotics\_sdk.providers package
===============================

Subpackages
-----------

.. toctree::

    rebotics_sdk.providers.tests

Submodules
----------

rebotics\_sdk.providers.admin module
------------------------------------

.. automodule:: rebotics_sdk.providers.admin
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.providers.base module
-----------------------------------

.. automodule:: rebotics_sdk.providers.base
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.providers.dataset module
--------------------------------------

.. automodule:: rebotics_sdk.providers.dataset
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.providers.facenet module
--------------------------------------

.. automodule:: rebotics_sdk.providers.facenet
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.providers.retailer module
---------------------------------------

.. automodule:: rebotics_sdk.providers.retailer
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.providers.shelf\_camera\_manager module
-----------------------------------------------------

.. automodule:: rebotics_sdk.providers.shelf_camera_manager
    :members:
    :undoc-members:
    :show-inheritance:

rebotics\_sdk.providers.utils module
------------------------------------

.. automodule:: rebotics_sdk.providers.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: rebotics_sdk.providers
    :members:
    :undoc-members:
    :show-inheritance:
